@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.57 2003/10/10 14:18:21 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.62 2003/12/01 17:39:52 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -60,7 +60,7 @@ char *base_desc[]  = {         /* Tooltips for each base value. */
 
 char *calc_res[] = {
     "accuracy", "base", "display", "mode", "showregisters", "trigtype",
-    "removezeroes"
+    "showzeroes", "showthousands"
 };
 
 char *dtype_str[] = {          /* Strings for each display mode value. */
@@ -171,8 +171,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("/"),
     N_("Divide"),
     NULL,
-    { 0,         0,             0,      0 },
-    { GDK_slash, GDK_KP_Divide, GDK_R5, 0 },
+    { 0,         0,             0,      GDK_SHIFT_MASK, 0 },
+    { GDK_slash, GDK_KP_Divide, GDK_R5, GDK_slash,      0 },
     '/',
     M_NONE,
     do_calc
@@ -407,8 +407,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("="),
     N_("Calculate result"),
     NULL,
-    { 0,         0,            0,          0 },
-    { GDK_equal, GDK_KP_Enter, GDK_Return, 0 },
+    { 0,         0,            0,          GDK_SHIFT_MASK, 0 },
+    { GDK_equal, GDK_KP_Enter, GDK_Return, GDK_equal,      0 },
     '=',
     M_NONE,
     do_calc
@@ -424,7 +424,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_calc
 },
 {
-    N_("1/x"),
+    N_("1/<i>x</i>"),
     N_("Reciprocal"),
     NULL,
     { 0, 0 },
@@ -434,7 +434,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_immed
 },
 {
-    N_("x<sup>2</sup>"),
+    N_("x<sup><i>2</i></sup>"),
     N_("Square"),
     NULL,
     { GDK_SHIFT_MASK, 0 },
@@ -770,7 +770,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_expno
 },
 {
-    N_("<i>e</i><sup>x</sup>"),
+    N_("e<sup><i>x</i></sup>"),
     N_("e to the power of displayed value"),
     N_("E to the x"),
     { GDK_SHIFT_MASK, 0 },
@@ -780,7 +780,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },
 {
-    N_("10<sup>x</sup>"),
+    N_("10<sup><i>x</i></sup>"),
     N_("10 to the power of displayed value"),
     N_("Ten to the x"),
     { GDK_SHIFT_MASK, 0 },
@@ -790,7 +790,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },       
 {        
-    N_("y<sup>x</sup>"),
+    N_("y<sup><i>x</i></sup>"),
     N_("y to the power of displayed value"),
     N_("Y to the x"),
     { 0, 0 },   
@@ -800,7 +800,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_calc
 },       
 {        
-    N_("x!"),
+    N_("<i>x</i>!"),
     N_("Factorial of displayed value"),
     N_("Factorial"),
     { GDK_SHIFT_MASK, 0 },
@@ -967,8 +967,8 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("Xor"),
     N_("Logical XOR"),
     NULL,
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_caret, 0 },
+    { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
+    { GDK_caret,      GDK_asciicircum, 0 },
     '^',
     M_NONE,
     do_calc
@@ -1018,6 +1018,7 @@ do_calctool(int argc, char **argv)
     }
 
     v->radix_char = get_radix_char();   /* Locale specific radix character. */
+    v->tsep_char  = get_tsep_char();  /* Locale specific thousands seperator. */
 
     init_text();               /* Setup text strings depending upon language. */
     init_vars();               /* Setup default values for variables. */
