@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.30 2003/10/13 15:37:37 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.34 2003/12/03 22:20:02 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -28,6 +28,68 @@ static char *make_eng_sci(int *, int);
 static char *make_fixed(int *, int, int);
 
 
+/* Add in the thousand separators characters if required and if we are
+ * currently in the decimal numeric base.
+ */
+
+void
+add_tsep()
+{
+    if (v->show_tsep && v->base == DEC) {
+	char *dstp, *radixp, *srcp;
+	int n;
+
+	/* Process the fractional part (if any). */
+	srcp = v->fnum + strlen(v->fnum) - 1;
+	dstp = v->tnum;
+	if ((radixp = strchr(v->fnum, v->radix_char)) != NULL) {
+            while (*srcp != v->radix_char) {
+    		*dstp++ = *srcp--;
+            }
+            *dstp++ = *srcp--;	   /* Copy over the radix char. */
+    	}
+
+    	/* Process the integer part, add in thousand separators. */
+    	n = 0;
+    	while (srcp >= v->fnum) {
+            *dstp++ = *srcp--;
+            n++;
+            if (n == 3 && srcp >= v->fnum) {
+		*dstp++ = ',';
+		n = 0;
+            }
+	}
+	*dstp++ = '\0';
+
+	/* Move from scratch pad to fnum, reversing the character order. */
+	srcp = v->tnum + strlen(v->tnum) - 1;
+	dstp = v->fnum;
+	while (srcp >= v->tnum) {
+            *dstp++ = *srcp--;
+	}
+	*dstp++ = '\0';
+    }
+}
+
+
+/* Remove the thousands separators (if any) in-situ. */
+
+void
+remove_tsep(char *str) {
+    char *srcp = str;
+    char *dstp = str;
+
+    while (*srcp != '\0') {
+        if (*srcp == ',') {
+            srcp++;
+            continue;
+        }
+        *dstp++ = *srcp++;
+    }
+    *dstp++ = '\0';
+}
+
+
 int
 char_val(char chr)
 {
@@ -174,6 +236,8 @@ make_fixed(int *MPnumber, int base, int cmax)
         *optr = '\0';
     }
 
+    add_tsep();
+
     return(v->fnum);
 }
 
@@ -202,12 +266,6 @@ make_number(int *MPnumber, int base, BOOLEAN mkFix, BOOLEAN ignoreError)
         (v->dtype == SCI) ||
         (v->dtype == FIX && val != 0.0 && (val > max_fix[base]))) {
         return(make_eng_sci(MPnumber, base));
-    } else if (v->dtype == FIX && val != 0.0 && mkFix) {
-        if (val <= min_fix[v->accuracy][base]) {
-            return(make_eng_sci(MPnumber, base));
-        } else {
-            return(make_fixed(MPnumber, base, MAX_DIGITS));
-        }
     } else {
         return(make_fixed(MPnumber, base, MAX_DIGITS));
     }
@@ -335,6 +393,9 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
     i = 0;
     mpcim(&i, MPval);
     mpcim(&basevals[(int) base], MPbase);
+
+    remove_tsep(str);
+
     optr = str;
     while ((inum = char_val(*optr)) >= 0) {
         mpmul(MPval, MPbase, MPval);
@@ -412,6 +473,24 @@ paren_disp(char c)
             }
         }
         v->display[n-1] = '\0';
+
+    } else if (c == '(') {
+
+/* If this is the first left parenthesis being displayed and there is no
+ * current arithmetic operand, then the current display is initially cleared
+ * to avoid the confusion of showing something like "0(".
+ */
+
+        if (v->noparens == 1 && v->cur_op == '?') {
+            n = 0;
+            v->display[n] = '\0';
+        }
+
+        if (n < MAXLINE-1) {
+            v->display[n]   = c;
+            v->display[n+1] = '\0';
+        }
+
     } else {                           /* It must be an ordinary character. */
         if (n < MAXLINE-1) {
             v->display[n]   = c;
